
**********************************************
**GLASS**: Generator for Large Scale Structure
**********************************************

.. image:: https://badges.gitter.im/glass-dev/glass.svg
   :alt: Join the chat at https://gitter.im/glass-dev/glass
   :target: https://gitter.im/glass-dev/glass?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

This is an early access repository for GLASS.

For the time being, the best way to install up-to-date code is to use the
repository::

    pip install git+https://github.com/glass-dev/glass.git

You might want to have a look at the `documentation`__, as far as it exists at
this stage.  There is also an `examples`__ project to get you started.

__ https://glass.readthedocs.io/
__ https://glass.readthedocs.io/projects/examples/

If you want to run the examples yourself, you currently also need the `CAMB
module for GLASS`__::

    pip install git+https://github.com/glass-dev/glass-camb.git

__ https://github.com/glass-dev/glass-camb

(Note that the code currently does not have a license for distribution.  This is
done on purpose so that we can keep some vague notion of control over the code
before we have our v1.0 release and paper.  The code will be licensed under the
MIT license.)
